# hep-basestack

[![Coverage Status](https://coveralls.io/repos/github/achim1/hepbasestack/badge.svg?branch=master)](https://coveralls.io/github/achim1/hepbasestack?branch=master)
[![Documentation Status](https://readthedocs.org/projects/hepbasestack/badge/?version=latest)](https://hepbasestack.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://travis-ci.org/achim1/hepbasestack.svg?branch=master)](https://travis-ci.org/achim1/hepbasestack)

Collection of recurring snippets in common projects which includes logging, adjusting matploltib styles, setting plot layouts, 
determinining if something is executed within and ipython notebook etc.

The hep in the name referes to high-energy particlephysiscs and the commonly used software stack numpy/matplotlib, which this
packages should help to handle more comfortly with the provided snippets. However, it is not tied to the use in high-energy physics.

### Installation

`pip install hepbasestack`
